@@ -18,7 +18,7 @@ def rolling_forecasting(forecasting_model, X, y, n=252, s=63, s_eval= None, meth
     if n is not None and s_eval is not None:
         roll = rolling._EvalRollingMechanism(idx, n=n, s=s, s_eval = s_eval)
 
-    for slice_n, slice_s in roll():
+    for slice_n, slice_s, slice_s_eval in roll():
         # Select X
         X_train = X.loc[slice_n].copy()
         y_train = y.loc[slice_n].copy()
