@@ -96,14 +96,6 @@ def alpha_16(data = None, contravariant = -1., lag = 5, **kwargs):
 
 
 
-
-def dd_threshold(data = None, threshold=1., contravariant = -1., **kwargs):
-    ratio = data['high'][-1]/data['high'][0]
-    if ratio > threshold:
-        return contravariant
-    else :
-        return -contravariant
-
 def lead_lag_indicator(data = None, lead=3, lag=5, contravariant = -1., **kwargs):
     output_sma_lead = data.close[-lead:].mean()
     output_sma_lag = data.close[-lag:].mean()
@@ -310,7 +302,7 @@ def slope_induced_cont(data = None, contravariant = -1., lag = 2, slope_column =
 
     return contravariant*signal
 
-def counting_candles(data= None, threshold = 1., contravariant = -1., lag = 2, **kwargs):
+def counting_candles(data= None, low_threshold = 0.3, up_threshold = 0.8, contravariant = -1., lag = 2, **kwargs):
     data['close_diff']= (data.close.diff() >= 0.).astype(float)
 
     ## aggregating the volumes by lag
@@ -333,20 +325,14 @@ def counting_candles(data= None, threshold = 1., contravariant = -1., lag = 2, *
     data = data[::-lag]
     data = data.iloc[::-1]
 
-    me_values = (data.close.diff() >= 0.).astype(float).value_counts()
-    try:
-        one_count = me_values[1.]
-    except KeyError:
-        one_count = 0
-    try:
-        zero_count = me_values[0.]
-    except KeyError:
-        zero_count = None
-    if zero_count is not None:
-        ratio = one_count/zero_count
-        if ratio >= threshold:
-            return -contravariant
-        else:
-            return contravariant
-    else :
-        return -contravariant
\ No newline at end of file
+
+    data['positive_candle_pct_rank'] = data['aggregated_close_diff'].rank(pct=True)
+
+    ratio_rank = data['positive_candle_pct_rank'].iloc[-1]
+
+    if ratio_rank >= up_threshold:
+        return contravariant
+    elif ratio_rank <= low_threshold:
+        return -contravariant
+    else:
+        return np.nan
\ No newline at end of file
